@@ -750,7 +750,7 @@ def _get_freeze_source_packages(
 def _get_installed_required_package_names(
     package_name: str,
     parallelize: bool = False,
-    traversed_package_names: Container[str] = ()
+    traversed_package_names: Collection[str] = ()
 ) -> Set[str]:
     """
     Get the package name for all of a package's requirements, including extras
@@ -775,29 +775,37 @@ def _get_installed_required_package_names(
             )
         ))
     except pkg_resources.DistributionNotFound as distribution_not_found_error:
-        setup_script_path: str = ''
+        found: bool = False
+        required_package_names = set()
         for entry in pkg_resources.working_set.entries:
             try:
-                setup_script_path = find.setup_script_path(entry)
-                break
+                setup_script_path: str = find.setup_script_path(entry)
+                setup_script: SetupScript = SetupScript(setup_script_path)
+                found = canonicalize_name(
+                    setup_script.get('name', '')
+                ) == package_name
+                if found:
+                    for requirement in (
+                        list(setup_script.get('install_requires', [])) +
+                        list(setup_script.get('setup_requires', [])) +
+                        list(chain(*setup_script.get(
+                            'extras_require', {}
+                        ).values()))
+                    ):
+                        required_package_names.add(
+                            canonicalize_name(
+                                get_requirement_package_identifier(
+                                    requirement
+                                )
+                            )
+                        )
+                    break
             except FileNotFoundError:
                 continue
-        if not setup_script_path:
-            return set()
-        setup_script: SetupScript = SetupScript(setup_script_path)
-        required_package_names = set()
-        for requirement in (
-            list(setup_script.get('install_requires', [])) +
-            list(setup_script.get('setup_requires', [])) +
-            list(chain(*setup_script.get('extras_require', {}).values()))
-        ):
-            required_package_names.add(
-                canonicalize_name(
-                    get_requirement_package_identifier(
-                        requirement
-                    )
-                )
-            )
+            if found:
+                break
+        if not found:
+            return required_package_names
     required_package_names -= traversed_package_names
     if not required_package_names:
         return required_package_names
@@ -807,7 +815,7 @@ def _get_installed_required_package_names(
         parallelize = False
         parallelize_recursive_calls = True
     traversed_package_names = tuple(sorted(traversed_package_names))
-    arguments: Iterable[Tuple[str, bool]] = (
+    arguments: Iterable[Tuple[str, bool, Tuple[str, ...]]] = (
         (
             required_package_name,
             parallelize_recursive_calls,
@@ -816,7 +824,6 @@ def _get_installed_required_package_names(
         for required_package_name in
         required_package_names
     )
-    parallelize = False
     if parallelize:
         pool: Pool
         with Pool() as pool:
@@ -868,8 +875,8 @@ def get_freeze(
     package_name: str
     # Normalize excluded/included package names and expand to include packages
     # required by the excluded/included package
-    exclude = set(_flatten_requirements(exclude))
     include = set(_flatten_requirements(include))
+    exclude = set(_flatten_requirements(exclude)) - include
     source_package_names: Dict[str, str] = _get_freeze_source_packages(
         exclude=exclude,
         include=include
